# The Bayes factor provided by ttestBF tests the null hypothesis that the mean (or mean difference)
# of a normal population is µ0 (argument mu). Specifically, the Bayes factor compares two hypotheses:
# that the standardized effect size is 0, or that the standardized effect size is not 0. For one-sample
# tests, the standardized effect size is (µ − µ0)/σ; for two sample tests, the standardized effect size is
# (µ2 − µ1)/σ.
# A noninformative Jeffreys prior is placed on the variance of the normal population, while a Cauchy
# prior is placed on the standardized effect size. The rscale argument controls the scale of the prior
# distribution, with rscale=1 yielding a standard Cauchy prior. See the references below for more
# details.
# For the rscale argument, several named values are recognized: "medium", "wide", and "ultrawide".
# These correspond to r scale values of √
# 2/2, 1, and √
# 2 respectively.
# The Bayes factor is computed via Gaussian quadrature.

#BayesFactor
https://cran.r-project.org/web/packages/BayesFactor/BayesFactor.pdf
#install.packages("BayesFactor")
library(BayesFactor)
library(BayesFactor)
dataexp2 <- 
  read.table("http://www.irrational-decisions.com/phd-thesis/dataexp2.txt",
             header=TRUE, sep="", na.strings="NA", dec=".", strip.white=TRUE)

## paired t test
ttestBF(x = dataexp2$v00, y = dataexp2$v01, paired=TRUE, mu=0)

samples = ttestBF(x = dataexp2$v00, y = dataexp2$v01, paired=TRUE, mu=0, posterior = TRUE, iterations = 2000)
plot(samples[,"mu"])

#replicates JASP with r=0.707
with(dataexp2, (t.test(v00, v01, alternative='two.sided', conf.level=.95, paired=TRUE)))
t=c(2.8757)
N=c(62)
## Use rscale=1 and one-sided test to be
## consistent with Rouder & Morey (2011)
bf = meta.ttestBF(t, N, rscale=0.707, nullInterval=c(0, Inf))
bf[1]
## plot posterior distribution of delta, assuming alternative
## turn off progress bar for example
samples = posterior(bf[1], iterations = 1000, progress = TRUE)
## Note that posterior() respects the nullInterval
plot(samples)
summary(samples)




# This function computes mata-analytic Bayes factors, or samples from the posterior, for one- and
# two-sample designs where multiple t values have been observed.

## Bem's (2010) data (see Rouder & Morey, 2011)
t=c(-.15,2.39,2.42,2.43)
N=c(100,150,97,99)
## Using rscale=1 and one-sided test to be
## consistent with Rouder & Morey (2011)
bf = meta.ttestBF(t, N, rscale=1, nullInterval=c(0, Inf))
bf[1]
## plot posterior distribution of delta, assuming alternative
## turn off progress bar for example
samples = posterior(bf[1], iterations = 1000, progress = FALSE)
## Note that posterior() respects the nullInterval
plot(samples)
summary(samples)


