#Bayesian Power Analysis

if(!require(BayesFactor)){install.packages('BayesFactor')}
library(BayesFactor) 

D<-0.12 #Set the true effect size
n<-100 #Set sample size of your study (number in each group)
nSim<-1000 #Set number of simulations (it takes a while, be patient)
rscaleBF<-sqrt(2)/2 #Set effect size of alternative hypothesis (default = sqrt(2)/2, or 0.707)
threshold<-1 #Set threshold for 'support' - e.g., 3, 10, or 30

bf<-numeric(nSim)

# create progress bar because it might take a while
pb <- winProgressBar(title = "progress bar", min = 0, max = nSim, width = 300)

for(i in 1:nSim){ #for each simulated experiment
  setWinProgressBar(pb, i, title=paste(round(i/nSim*100, 1), "% done"))
  x<-rnorm(n = n, mean = 0, sd = 1)
  y<-rnorm(n = n, mean = D, sd = 1) 
  bf[i] <- exp((ttestBF(x,y, rscale = rscaleBF))@bayesFactor$bf)
}
close(pb)#close progress bar

supportH0 <- sum(bf<(1/threshold))/nSim
supportH1 <- sum(bf>threshold)/nSim

cat("The probability of observing support for the null hypothesis is ",supportH0)
cat("The probability of observing support for the alternative hypothesis is ",supportH1)

hist(log(bf), breaks=20)