#This function computes the test and key test quantities for the paired t-test for equivalence, as documented
#in Wellek (2003, pp 77-80). This function computes the test from the mean and standard
#deviation of a sample of paired differences from a normally-distributed population.

#The function as documented by Wellek (2003) uses units relative to the standard deviation, noting
#(p. 12) that 0.25 corresponds to a strict test and 0.5 to a liberal test.

#https://cran.r-project.org/web/packages/equivalence/equivalence.pdf

dataexp2 <- 
  read.table("http://www.irrational-decisions.com/phd-thesis/dataexp2.txt",
             header=TRUE, sep="", na.strings="NA", dec=".", strip.white=TRUE)
#https://cran.r-project.org/web/packages/equivalence/equivalence.pdf
#install.packages("equivalence")
library(equivalence)
ptte.data(dataexp2$v00 - dataexp2$v01)

#data(dataexp2)
ptte.stat(mean(dataexp2$v00 - dataexp2$v01, na.rm=TRUE),
sd(dataexp2$v00 - dataexp2$v01, na.rm=TRUE),
sum(!is.na(dataexp2$v00 - dataexp2$v01)))



#tr the proportion (percent/100) of the data set to be trimmed
#Epsilon the magnitude of the region of similarity
#The rtost function is wrapped around the yuen PairedData t test, a robust variant of the t test using
#trimmed means and winsorized variances. It provides tosts for the same range of designs, accepts
#the same arguments, and handles missing values the same way as tost equivalence. For the tost, the
#user must set epsilon, which is the magnitude of region similarity. Warning: with tr > 0.25 type I
#error control might be poor.
rtost(dataexp2$v00, dataexp2$v01, alpha = 0.05, epsilon = 0.2, tr = 0.1)


equivalence.xyplot(dataexp2$v00 ~ dataexp2$v01,
alpha=0.05, b0.ii=0.05, b1.ii=0.05,
add.smooth=FALSE, b0.absolute=FALSE,
xlab=expression(paste("Difference of means(", mu[2],- mu[2], ")", sep="")),
ylab="expressions"
)

tost(dataexp2$v00, dataexp2$v01, epsilon = 0.1, paired = TRUE)
	Paired TOST

data:  dataexp2$v00 and dataexp2$v01
df = 61
sample estimates:
mean of the differences 
              0.1248589 

Epsilon: 0.1 
95 percent two one-sided confidence interval (TOST interval):
 0.05234079 0.19737695
Null hypothesis of statistical difference is: not rejected 
TOST p-value: 0.715471



m[2] subscript
m^2 superscriript


#This test requires the assumption of normality of the population. Under that assumption the test is
#the uniformly most powerful invariant test (Wellek, 2003, pp. 78-79). 
#Epsilon the magnitude of the region of similarity

ptte.data(dataexp2$v00 - dataexp2$v01, alpha = 0.05, Epsilon = 0.05)